You are viewing a plain text version of this content. The canonical link for it is here.
Posted to dev@lucene.apache.org by "Johan Stuyts (JIRA)" <ji...@apache.org> on 2006/07/28 11:29:13 UTC

[jira] Created: (LUCENE-640) [PATCH] Performance improvement for doNext() of ConjunctionScorer

[PATCH] Performance improvement for doNext() of ConjunctionScorer
-----------------------------------------------------------------

                 Key: LUCENE-640
                 URL: http://issues.apache.org/jira/browse/LUCENE-640
             Project: Lucene - Java
          Issue Type: Improvement
          Components: Search
    Affects Versions: 2.0.0
            Reporter: Johan Stuyts
         Attachments: Lucene2ConjunctionScorerDoNextPerformance.patch

I was able to improve the performance of 'doNext() of 'ConjunctionScorer' by over 20% by storing the result of some calls that were performed multiple times in local variables. The test program invoked the method over 400,000 times on each run.

I ran the performance tests on: 
- Windows XP Pro SP2 
- Sun JDK 1.5.0_07 
- YourKit 5.5.4 
- Lucene trunk


-- 
This message is automatically generated by JIRA.
-
If you think it was sent incorrectly contact one of the administrators: http://issues.apache.org/jira/secure/Administrators.jspa
-
For more information on JIRA, see: http://www.atlassian.com/software/jira

        

---------------------------------------------------------------------
To unsubscribe, e-mail: java-dev-unsubscribe@lucene.apache.org
For additional commands, e-mail: java-dev-help@lucene.apache.org


[jira] Resolved: (LUCENE-640) [PATCH] Performance improvement for doNext() of ConjunctionScorer

Posted by "Paul Elschot (JIRA)" <ji...@apache.org>.
     [ https://issues.apache.org/jira/browse/LUCENE-640?page=com.atlassian.jira.plugin.system.issuetabpanels:all-tabpanel ]

Paul Elschot resolved LUCENE-640.
---------------------------------

    Resolution: Duplicate

Meanwhile LUCENE-443 and LUCENE-693 have solved/superseded this, so I think this issue can safely be closed.

> [PATCH] Performance improvement for doNext() of ConjunctionScorer
> -----------------------------------------------------------------
>
>                 Key: LUCENE-640
>                 URL: https://issues.apache.org/jira/browse/LUCENE-640
>             Project: Lucene - Java
>          Issue Type: Improvement
>          Components: Search
>    Affects Versions: 2.0.0
>            Reporter: Johan Stuyts
>         Attachments: Lucene2ConjunctionScorerDoNextPerformance.patch
>
>
> I was able to improve the performance of 'doNext() of 'ConjunctionScorer' by over 20% by storing the result of some calls that were performed multiple times in local variables. The test program invoked the method over 400,000 times on each run.
> I ran the performance tests on: 
> - Windows XP Pro SP2 
> - Sun JDK 1.5.0_07 
> - YourKit 5.5.4 
> - Lucene trunk

-- 
This message is automatically generated by JIRA.
-
You can reply to this email to add a comment to the issue online.


---------------------------------------------------------------------
To unsubscribe, e-mail: java-dev-unsubscribe@lucene.apache.org
For additional commands, e-mail: java-dev-help@lucene.apache.org


[jira] Updated: (LUCENE-640) [PATCH] Performance improvement for doNext() of ConjunctionScorer

Posted by "Johan Stuyts (JIRA)" <ji...@apache.org>.
     [ http://issues.apache.org/jira/browse/LUCENE-640?page=all ]

Johan Stuyts updated LUCENE-640:
--------------------------------

    Attachment: Lucene2ConjunctionScorerDoNextPerformance.patch

Optimization of 'doNext()' of 'ConjunctionScorer'.

> [PATCH] Performance improvement for doNext() of ConjunctionScorer
> -----------------------------------------------------------------
>
>                 Key: LUCENE-640
>                 URL: http://issues.apache.org/jira/browse/LUCENE-640
>             Project: Lucene - Java
>          Issue Type: Improvement
>          Components: Search
>    Affects Versions: 2.0.0
>            Reporter: Johan Stuyts
>         Attachments: Lucene2ConjunctionScorerDoNextPerformance.patch
>
>
> I was able to improve the performance of 'doNext() of 'ConjunctionScorer' by over 20% by storing the result of some calls that were performed multiple times in local variables. The test program invoked the method over 400,000 times on each run.
> I ran the performance tests on: 
> - Windows XP Pro SP2 
> - Sun JDK 1.5.0_07 
> - YourKit 5.5.4 
> - Lucene trunk

-- 
This message is automatically generated by JIRA.
-
If you think it was sent incorrectly contact one of the administrators: http://issues.apache.org/jira/secure/Administrators.jspa
-
For more information on JIRA, see: http://www.atlassian.com/software/jira

        

---------------------------------------------------------------------
To unsubscribe, e-mail: java-dev-unsubscribe@lucene.apache.org
For additional commands, e-mail: java-dev-help@lucene.apache.org